<?php
/**
 * A command for the money refill page
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 Ship-Simu Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class WebShipsimuRefillCommand extends BaseCommand implements Commandable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this command and sets the resolver instance
	 *
	 * @param	$resolverInstance	An instance of a command resolver
	 * @return	$commandInstance	The created command instance
	 */
	public static final function createWebShipsimuRefillCommand (CommandResolver $resolverInstance) {
		// Get a new instance
		$commandInstance = new WebShipsimuRefillCommand();

		// Set the resolver instance
		$commandInstance->setResolverInstance($resolverInstance);

		// Return the prepared instance
		return $commandInstance;
	}

	/**
	 * Executes the command with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Get template instance
		$templateInstance = $responseInstance->getTemplateInstance();

		// Set amount and type as variables
		$templateInstance->assignVariable('refill_done', $requestInstance->getRequestElement('type'));
		$templateInstance->assignVariable('amount'     , $requestInstance->getRequestElement('amount'));

		// This method does currently redirect if all goes right. Booking is done in filters
		$responseInstance->redirectToConfiguredUrl('refill_page_done');
	}

	/**
	 * Adds extra filters to the given controller instance
	 *
	 * @param	$controllerInstance		A controller instance
	 * @param	$requestInstance		An instance of a class with an Requestable interface
	 * @return	void
	 */
	public function addExtraFilters (Controller $controllerInstance, Requestable $requestInstance) {
		// Add user auth filter (we don't need an update of the user here because it will be redirected)
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('user_auth_filter'));

		// Add user status filter here
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('user_status_filter'));

		// Is the refill page active?
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('refill_page_filter'));

		// Verify password
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('account_password_filter'));

		// Verify CAPTCHA code
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('captcha_refill_verifier_filter'));

		// Verify refill request
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('refill_request_validator_filter'));

		// Construct config entry for wether automatic payment from API or waiting for approval
		$paymentTypeConfig = sprintf("refill_request_%s_payment_type", $requestInstance->getRequestElement('type'));

		// Prepare a filter based on the requested type we shall refill
		$filterName = sprintf("refill_request_%s_%s_book_filter",
			$requestInstance->getRequestElement('type'),
			$this->getConfigInstance()->getConfigEntry($paymentTypeConfig)
		);

		// Now, try to load that filter
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName($filterName));
	}
}

// [EOF]
?>
